# This is for the management of hosts and snapshots in the yaml config file.
# Anything for adding, removing, or modifying hosts or snapshots in the
# floatyhelper.yaml file belongs here. Anything for modifying the VMs themselves
# does not.
require 'floatyhelper/config'

class Groups
  def self.get_tags
    data = Config.load_data
    data['vms'].keys
  end

  def self.tag?(id)
    data = Config.load_data
    data['vms'].keys.include?(id)
  end

  def self.delete_tag(tag, data: nil)
    data ||= Config.load_data
    data['vms'].delete(tag)
    data['snapshots'].delete(tag) if data['snapshots'].keys.include?(tag)
    Config.write_data(data)
  end

  def self.delete_all
    data = Config.load_data
    data['vms'] = {}
    data['snapshots'] = {}
    Config.write_data(data)
  end

  def self.get_hosts(tag)
    data = Config.load_data
    data['vms'][tag]
  end

  def self.addhosts(hosts, tag)
    data = Config.load_data
    data['vms'] ||= {}
    tag ||= 'Blank Tag' # Removed the ability to do this
    hosts.each do |host|
      data['vms'][tag] ||= []
      data['vms'][tag] << host unless data['vms'][tag].include?(host)
    end
    Config.write_data(data)
  end

  def self.removehosts(hosts, tag)
    data = Config.load_data
    return if data['vms'][tag].nil?

    hosts.each do |host|
      data['vms'][tag] ||= []
      data['vms'][tag].delete(host)
      if data['snapshots'][tag]
        data['snapshots'][tag].each do |snaptag, _vals|
          data['snapshots'][tag][snaptag].delete(host)
        end
      end
      delete_tag(tag, data: data) if data['vms'][tag].empty?
    end
    Config.write_data(data)
  end

  def self.managed_host?(host)
    data = Config.load_data
    data['vms'].any? { |_tag, hosts| hosts.include?(host) }
  end

  def self.host_tag(host)
    data = Config.load_data
    raise 'Host not found' unless managed_host?(host)
    tags = data['vms'].select { |_tag, hosts| hosts.include?(host) }.keys
    tags[0]
  end
end
